@@ -25,6 +25,25 @@ tfpersp <- function (x, tf=tfspan(x), start=tfstart(tf), end=tfend(tf),
        ltheta=ltheta, lphi=lphi) #, col = fcol, shade = 0.4,...)
     }
 
+changeTSrepresentation <- function(x, newRepresentation){
+   if (mode(newRepresentation) == "character")  
+       if (newRepresentation == "tis") {
+          require("tis")
+          r <- do.call("as.tis", list(x)) 
+          }
+       else {
+  	  require("zoo")
+  	  dates <- as.Date(time(x))
+          r <- do.call(newRepresentation, list(x, dates))
+          }
+    else {
+       require("zoo")
+       dates <- as.Date(time(x))
+       r <- newRepresentation(x, dates)
+       }
+   r
+   }
+
 TSwriteXLS <- function(x, ..., FileName="R.xls", SheetNames=NULL,
                dateHeader="date", verbose = FALSE){
   # consider tempfile() in overwrite case 
@@ -77,8 +96,8 @@ as.weekly <- function(x, FUN=sum, na.rm=FALSE, foldFrom=end(x), periodicity = 7)
    # 7 for 7 day weeks.  tested only with daily to weekly, 
    #  periodicity <- 1/frequency(x) unfortunately does not work for daily
    #drop <- length(x) %% periodicity
-   addst <- periodicity - (periods(tfwindow(x, end= foldFrom)) %% periodicity) 
-   adden <- (periods(tfwindow(x, start= foldFrom))-1) %% periodicity 
+   addst <- periodicity - (Tobs(tfwindow(x, end= foldFrom)) %% periodicity) 
+   adden <- (Tobs(tfwindow(x, start= foldFrom))-1) %% periodicity 
    x <- tfExpand.zoo(x, add.start=addst, add.end  =adden)
    r <- as.matrix(x)
    #if (drop > 0) r <- r[ -(1:drop),, drop=FALSE]
@@ -125,7 +144,7 @@ as.annually <- function (x, FUN=sum, na.rm=FALSE, ...){
 
 rollAggregate <- function(x, FUN=sum, na.rm=FALSE, aggPeriods=4, ...){
    r <- as.matrix(x)
-   N <- periods(x)
+   N <- Tobs(x)
    rr <- array(NA, c(N, NCOL(r), aggPeriods))
    rr[,,1] <- r
    for (i in 1:(aggPeriods-1)) rr[(1+i):N,,(1+i)] <- r[1:(N-i),]
